@@ -107,9 +107,6 @@ class Parser:
 
     def write_packet(self, packet):
 
-        self.nucleus_running = True
-        self.packet_timestamp = datetime.now()
-
         if self._queuing['packet'] is True:
 
             if self.packet_queue.full():
@@ -777,6 +774,3 @@ class Parser:
 
             else:
                 time.sleep(0.01)
-
-            if (datetime.now() - self.packet_timestamp).seconds >= 1:
-                self.nucleus_running = False
